Documentation
¶
Index ¶
- func BubbleNeighborhood(distance float64) float64
- func ConeNeighborhood(distance float64) float64
- func CoolingFactor(coolingFunction string, progress float64) float64
- func Distance(distanceFunction string, from, to []float64) float64
- func EpanechicovNeighborhood(distance float64) float64
- func EuclideanDistance(from, to []float64) float64
- func GaussianNeighborhood(distance float64) float64
- func HardCooling(progress float64) float64
- func LinearCooling(progress float64) float64
- func ManhattanDistance(from, to []float64) float64
- func MediumCooling(progress float64) float64
- func NeighborhoodInfluence(neighborhoodFunction string, distance float64) float64
- func SoftCooling(progress float64) float64
- type CoolingFunction
- type DistanceFunction
- type NeighborhoodFunction
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BubbleNeighborhood ¶
BubbleNeighborhood returns the influence for the specified distance.
func ConeNeighborhood ¶
ConeNeighborhood returns the influence for the specified distance.
func CoolingFactor ¶
CoolingFactor returns the cooling factors based on the selected coolingFunction.
func Distance ¶
Distance returns the distance between two points based on the selected distanceFunction.
func EpanechicovNeighborhood ¶
EpanechicovNeighborhood returns the influence for the specified distance.
func EuclideanDistance ¶
EuclideanDistance returns the euclidean distance between two points.
Note: Dimensions that include NaNs are ignored.
func GaussianNeighborhood ¶
GaussianNeighborhood returns the influence for the specified distance.
func HardCooling ¶
HardCooling returns the hard exponential cooling factor for progress.
func LinearCooling ¶
LinearCooling returns the linear cooling factor for progress.
func ManhattanDistance ¶
ManhattanDistance returns the manhattan distance between two points.
Note: Dimensions that include NaNs are ignored.
func MediumCooling ¶
MediumCooling returns the medium exponential cooling factor for progress.
func NeighborhoodInfluence ¶
NeighborhoodInfluence returns the influence of the distance based on the selected neighborhoodFunction.
func SoftCooling ¶
SoftCooling returns the soft exponential cooling factor for progress.
Types ¶
type CoolingFunction ¶
A CoolingFunction calculates the cooling alpha [1..0] for an input value [0..1].
type DistanceFunction ¶
A DistanceFunction calculates the distance between to points.
type NeighborhoodFunction ¶
A NeighborhoodFunction calculates the influence [1..0] of a distance [0..1..2].